@@ -5,12 +5,12 @@
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
  *  of the License, or (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- * 
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
@@ -19,13 +19,13 @@
 
 #include <config.h>
 #include <string.h>
+#include <locale.h>
 
 #include <glib.h>
 #include <gio/gio.h>
-
-#include <xfconf/xfconf.h>
 #include <gtk/gtk.h>
 
+#include <xfconf/xfconf.h>
 #include <libxfce4ui/libxfce4ui.h>
 
 #include "file.h"
@@ -33,6 +33,8 @@
 #include "settings.h"
 #include "main_window.h"
 #include "preferences_dialog.h"
+#include "util.h"
+
 
 
 gboolean version = FALSE;
@@ -40,17 +42,13 @@ gboolean start_fullscreen = FALSE;
 gboolean start_slideshow = FALSE;
 gboolean show_settings = FALSE;
 
-typedef struct {
-    RsttoImageList *image_list;
-    gint argc;
-    gchar **argv;
-    gint iter;
-    GtkWidget *window;
-} RsttoOpenFiles;
+
 
 static gboolean
 cb_rstto_open_files (gpointer user_data);
 
+
+
 static GOptionEntry entries[] =
 {
     {    "version", 'V', G_OPTION_FLAG_IN_MAIN, G_OPTION_ARG_NONE, &version,
@@ -76,19 +74,30 @@ static GOptionEntry entries[] =
     { NULL, ' ', 0, 0, NULL, NULL, NULL }
 };
 
+
+
+typedef struct {
+    RsttoImageList *image_list;
+    gint argc;
+    gchar **argv;
+    gint iter;
+    GtkWidget *window;
+} RsttoOpenFiles;
+
+
+
 int
-main(int argc, char **argv)
+main (int argc, char **argv)
 {
     GError *cli_error = NULL;
     RsttoSettings *settings;
     RsttoImageList *image_list;
     GtkWidget *window;
 
-    #ifdef ENABLE_NLS
+    setlocale (LC_ALL, "");
     bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
     textdomain (GETTEXT_PACKAGE);
-    #endif
 
     if (!gtk_init_with_args (&argc, &argv, NULL, entries, PACKAGE, &cli_error))
     {
@@ -115,10 +124,10 @@ main(int argc, char **argv)
 
     xfconf_init (NULL);
 
-    gtk_window_set_default_icon_name ("org.xfce.ristretto");
+    gtk_window_set_default_icon_name (RISTRETTO_APP_ID);
     settings = rstto_settings_new ();
 
-    if (FALSE == show_settings)
+    if (! show_settings)
     {
         image_list = rstto_image_list_new ();
         window = rstto_main_window_new (image_list, FALSE);
@@ -133,23 +142,24 @@ main(int argc, char **argv)
             rof.iter = 1;
             rof.window = window;
 
-            gdk_threads_add_idle (cb_rstto_open_files, &rof);
+            /* add weak pointers to guard our handler */
+            g_object_add_weak_pointer (G_OBJECT (window), (gpointer *) &(rof.window));
+            g_object_add_weak_pointer (G_OBJECT (image_list), (gpointer *) &(rof.image_list));
+            g_idle_add (cb_rstto_open_files, &rof);
 
-            if (TRUE == rstto_settings_get_boolean_property (
-                        settings,
-                        "maximize-on-startup"))
+            if (rstto_settings_get_boolean_property (settings, "maximize-on-startup"))
             {
                 gtk_window_maximize (GTK_WINDOW (window));
             }
         }
 
         /* Start fullscreen */
-        if (TRUE == start_fullscreen)
+        if (start_fullscreen)
         {
            gtk_window_fullscreen (GTK_WINDOW (window));
         }
 
-        g_signal_connect (G_OBJECT(window), "destroy", G_CALLBACK (gtk_main_quit), NULL);
+        g_signal_connect (window, "destroy", G_CALLBACK (gtk_main_quit), NULL);
         gtk_widget_show_all (window);
 
         gtk_main ();
@@ -172,7 +182,7 @@ main(int argc, char **argv)
 
     g_object_unref (settings);
 
-    xfconf_shutdown();
+    xfconf_shutdown ();
 
     return 0;
 }
@@ -188,6 +198,9 @@ cb_rstto_open_files (gpointer user_data)
     RsttoImageListIter *iter = NULL;
     const gchar *content_type;
 
+    if (rof->image_list == NULL || rof->window == NULL)
+        return FALSE;
+
     if (rof->argc > 2)
     {
         if (rof->iter < rof->argc)
@@ -204,7 +217,7 @@ cb_rstto_open_files (gpointer user_data)
                     if (strncmp (content_type, "image/", 6) == 0)
                     {
                         r_file = rstto_file_new (file);
-                        if (rstto_image_list_add_file (rof->image_list, r_file, NULL) == TRUE)
+                        if (rstto_image_list_add_file (rof->image_list, r_file, NULL))
                         {
                             rstto_main_window_add_file_to_recent_files (file);
                         }
@@ -212,6 +225,7 @@ cb_rstto_open_files (gpointer user_data)
                         r_file = NULL;
                     }
 
+                    g_object_unref (file_info);
                 }
             }
             rof->iter++;
@@ -237,6 +251,8 @@ cb_rstto_open_files (gpointer user_data)
                 {
                     /* TODO: show error dialog */
                 }
+
+                g_object_unref (file_info);
             }
         }
 
@@ -251,34 +267,32 @@ cb_rstto_open_files (gpointer user_data)
             p_file = g_file_get_parent (file);
 
             /* Open the directory */
-            rstto_image_list_set_directory (rof->image_list, p_file, NULL);
-
-            /* This call adds the contents of the
-             * directory asynchronously.
-             */
-            rstto_image_list_add_file (
-                    rof->image_list,
-                    r_file,
-                    NULL);
+            rstto_image_list_set_directory (rof->image_list, p_file, r_file, NULL);
 
             /* Point the iterator to the correct image */
             rstto_image_list_iter_find_file (iter, r_file);
 
+            g_object_unref (p_file);
             g_object_unref (r_file);
             r_file = NULL;
         }
         else
         {
             /* Open the directory */
-            rstto_image_list_set_directory (rof->image_list, file, NULL);
+            rstto_image_list_set_directory (rof->image_list, file, NULL, NULL);
 
             /* Point the iterator to the correct image */
             rstto_image_list_iter_set_position (iter, 0);
         }
 
-        if (TRUE == start_slideshow)
+        if (start_slideshow)
         {
-            rstto_main_window_play_slideshow (RSTTO_MAIN_WINDOW(rof->window));
+            rstto_main_window_play_slideshow (RSTTO_MAIN_WINDOW (rof->window));
+        }
+
+        if (file != NULL)
+        {
+            g_object_unref (file);
         }
 
     }
