@@ -5,12 +5,12 @@
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
  *  of the License, or (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- * 
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
@@ -21,23 +21,77 @@
 
 #include "monitor_chooser.h"
 
+
+
 #define RSTTO_MAX_MONITORS 9
 
-typedef struct {
+enum
+{
+    RSTTO_MONITOR_CHOOSER_SIGNAL_CHANGED = 0,
+    RSTTO_MONITOR_CHOOSER_SIGNAL_COUNT
+};
+
+static gint rstto_monitor_chooser_signals[RSTTO_MONITOR_CHOOSER_SIGNAL_COUNT];
+
+typedef struct _Monitor Monitor;
+typedef struct _MonitorPosition MonitorPosition;
+
+
+
+static gboolean
+rstto_monitor_chooser_draw (GtkWidget *widget,
+                            cairo_t *cr);
+static void
+rstto_monitor_chooser_realize (GtkWidget *widget);
+static void
+rstto_monitor_chooser_get_preferred_width (GtkWidget *widget,
+                                           gint *minimal_width,
+                                           gint *natural_width);
+static void
+rstto_monitor_chooser_get_preferred_height (GtkWidget *widget,
+                                            gint *minimal_height,
+                                            gint *natural_height);
+static void
+rstto_monitor_chooser_size_allocate (GtkWidget *widget,
+                                     GtkAllocation *allocation);
+
+
+static gboolean
+rstto_monitor_chooser_paint (GtkWidget *widget,
+                             cairo_t *ctx);
+static void
+cb_rstto_button_press_event (GtkWidget *widget,
+                             GdkEventButton *event);
+static void
+paint_monitor (GtkWidget *widget,
+               cairo_t *cr,
+               gdouble x,
+               gdouble y,
+               gdouble width,
+               gdouble height,
+               gchar *label,
+               Monitor *monitor,
+               gboolean active);
+
+
+
+struct _Monitor
+{
     gint width;
     gint height;
 
     cairo_surface_t *image_surface;
-} Monitor;
+};
 
-typedef struct {
+struct _MonitorPosition
+{
     guint x;
     guint y;
     guint width;
     guint height;
-} MonitorPosition;
+};
 
-struct _RsttoMonitorChooserPriv
+struct _RsttoMonitorChooserPrivate
 {
     Monitor **monitors;
     gint n_monitors;
@@ -46,102 +100,31 @@ struct _RsttoMonitorChooserPriv
     MonitorPosition monitor_positions[RSTTO_MAX_MONITORS];
 };
 
-static GtkWidgetClass *parent_class = NULL;
+
+
+G_DEFINE_TYPE_WITH_PRIVATE (RsttoMonitorChooser, rstto_monitor_chooser, GTK_TYPE_WIDGET)
+
+
 
 static void
-rstto_monitor_chooser_init(GTypeInstance *instance, gpointer g_class);
-
-static void
-rstto_monitor_chooser_class_init(gpointer g_class, gpointer class_data);
-
-static void
-rstto_monitor_chooser_finalize(GObject *object);
-
-static void
-rstto_monitor_chooser_realize(GtkWidget *widget);
-static void
-rstto_monitor_chooser_get_preferred_width(GtkWidget *, gint *, gint *);
-static void
-rstto_monitor_chooser_get_preferred_height(GtkWidget *, gint *, gint *);
-static void
-rstto_monitor_chooser_size_allocate(GtkWidget *, GtkAllocation *);
-static gboolean 
-rstto_monitor_chooser_draw(GtkWidget *, cairo_t *);
-static gboolean
-rstto_monitor_chooser_paint(GtkWidget *widget, cairo_t *ctx);
-
-static void
-cb_rstto_button_press_event (GtkWidget *, GdkEventButton *event);
-
-static void
-paint_monitor ( GtkWidget *widget,
-                cairo_t *cr,
-                gdouble x,
-                gdouble y,
-                gdouble width,
-                gdouble height,
-                gchar *label,
-                Monitor *monitor,
-                gboolean active);
-
-enum
+rstto_monitor_chooser_init (RsttoMonitorChooser *chooser)
 {
-    RSTTO_MONITOR_CHOOSER_SIGNAL_CHANGED = 0,
-    RSTTO_MONITOR_CHOOSER_SIGNAL_COUNT
-};
-
-static gint
-rstto_monitor_chooser_signals[RSTTO_MONITOR_CHOOSER_SIGNAL_COUNT];
-
-GType
-rstto_monitor_chooser_get_type (void)
-{
-    static GType rstto_monitor_chooser_type = 0;
-
-    if (!rstto_monitor_chooser_type)
-    {
-        static const GTypeInfo rstto_monitor_chooser_info = 
-        {
-            sizeof (RsttoMonitorChooserClass),
-            NULL,
-            NULL,
-            rstto_monitor_chooser_class_init,
-            NULL,
-            NULL,
-            sizeof (RsttoMonitorChooser),
-            0,
-            rstto_monitor_chooser_init,
-            NULL
-        };
-
-        rstto_monitor_chooser_type = g_type_register_static (GTK_TYPE_WIDGET, "RsttoMonitorChooser", &rstto_monitor_chooser_info, 0);
-    }
-    return rstto_monitor_chooser_type;
-}
-
-static void
-rstto_monitor_chooser_init(GTypeInstance *instance, gpointer g_class)
-{
-    RsttoMonitorChooser *chooser = RSTTO_MONITOR_CHOOSER (instance);
-
-    chooser->priv = g_new0(RsttoMonitorChooserPriv, 1);
+    chooser->priv = rstto_monitor_chooser_get_instance_private (chooser);
     chooser->priv->selected = -1;
     chooser->priv->monitors = g_new0 (Monitor *, 1);
 
-    g_signal_connect(G_OBJECT(chooser), "button-press-event", G_CALLBACK(cb_rstto_button_press_event), NULL);
+    g_signal_connect (chooser, "button-press-event",
+                      G_CALLBACK (cb_rstto_button_press_event), NULL);
 
-    gtk_widget_set_redraw_on_allocate(GTK_WIDGET(chooser), TRUE);
-    gtk_widget_set_events (GTK_WIDGET(chooser),
+    gtk_widget_set_redraw_on_allocate (GTK_WIDGET (chooser), TRUE);
+    gtk_widget_set_events (GTK_WIDGET (chooser),
                            GDK_POINTER_MOTION_MASK);
 }
 
 static void
-rstto_monitor_chooser_class_init(gpointer g_class, gpointer class_data)
+rstto_monitor_chooser_class_init (RsttoMonitorChooserClass *klass)
 {
-    GtkWidgetClass *widget_class = g_class;
-    GObjectClass *object_class = g_class;
-
-    parent_class = g_type_class_peek_parent(g_class);
+    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
     widget_class->draw = rstto_monitor_chooser_draw;
     widget_class->realize = rstto_monitor_chooser_realize;
@@ -149,10 +132,8 @@ rstto_monitor_chooser_class_init(gpointer g_class, gpointer class_data)
     widget_class->get_preferred_height = rstto_monitor_chooser_get_preferred_height;
     widget_class->size_allocate = rstto_monitor_chooser_size_allocate;
 
-    object_class->finalize = rstto_monitor_chooser_finalize;
-
-    rstto_monitor_chooser_signals[RSTTO_MONITOR_CHOOSER_SIGNAL_CHANGED] = g_signal_new("changed",
-            G_TYPE_FROM_CLASS(g_class),
+    rstto_monitor_chooser_signals[RSTTO_MONITOR_CHOOSER_SIGNAL_CHANGED] = g_signal_new ("changed",
+            G_TYPE_FROM_CLASS (klass),
             G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
             0,
             NULL,
@@ -163,18 +144,13 @@ rstto_monitor_chooser_class_init(gpointer g_class, gpointer class_data)
             NULL);
 }
 
-static void
-rstto_monitor_chooser_finalize(GObject *object)
-{
-}
-
 /**
  * rstto_monitor_chooser_realize:
  * @widget:
  *
  */
 static void
-rstto_monitor_chooser_realize(GtkWidget *widget)
+rstto_monitor_chooser_realize (GtkWidget *widget)
 {
     GdkWindowAttr attributes;
     gint attributes_mask;
@@ -207,19 +183,19 @@ rstto_monitor_chooser_realize(GtkWidget *widget)
 }
 
 static void
-rstto_monitor_chooser_get_preferred_width(GtkWidget *widget, gint *minimal_width, gint *natural_width)
+rstto_monitor_chooser_get_preferred_width (GtkWidget *widget, gint *minimal_width, gint *natural_width)
 {
     *minimal_width = *natural_width = 400;
 }
 
 static void
-rstto_monitor_chooser_get_preferred_height(GtkWidget *widget, gint *minimal_height, gint *natural_height)
+rstto_monitor_chooser_get_preferred_height (GtkWidget *widget, gint *minimal_height, gint *natural_height)
 {
     *minimal_height = *natural_height = 200;
 }
 
 static void
-rstto_monitor_chooser_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
+rstto_monitor_chooser_size_allocate (GtkWidget *widget, GtkAllocation *allocation)
 {
     gtk_widget_set_allocation (widget, allocation);
     if (gtk_widget_get_realized (widget))
@@ -233,7 +209,7 @@ rstto_monitor_chooser_size_allocate(GtkWidget *widget, GtkAllocation *allocation
 }
 
 static gboolean
-rstto_monitor_chooser_draw(GtkWidget *widget, cairo_t *cr)
+rstto_monitor_chooser_draw (GtkWidget *widget, cairo_t *cr)
 {
     cairo_save (cr);
     rstto_monitor_chooser_paint (widget, cr);
@@ -242,24 +218,22 @@ rstto_monitor_chooser_draw(GtkWidget *widget, cairo_t *cr)
 }
 
 static gboolean
-rstto_monitor_chooser_paint(GtkWidget *widget, cairo_t *ctx)
+rstto_monitor_chooser_paint (GtkWidget *widget, cairo_t *ctx)
 {
     RsttoMonitorChooser *chooser = RSTTO_MONITOR_CHOOSER (widget);
     Monitor *monitor;
-
+    gchar *label;
+    gint row_width, id;
     gdouble width, height;
-    gchar *label = NULL;
-    gint row_width = 0;
-    gint id = 0;
-    gdouble alloc_width = (gdouble)gtk_widget_get_allocated_width (widget);
-    gdouble alloc_height = (gdouble)gtk_widget_get_allocated_height (widget);
+    gdouble alloc_width = gtk_widget_get_allocated_width (widget);
+    gdouble alloc_height = gtk_widget_get_allocated_height (widget);
     GtkStyleContext *context = gtk_widget_get_style_context (widget);
 
     gtk_render_background (context, ctx, 0, 0, alloc_width, alloc_height);
 
     if (chooser->priv->n_monitors > 1)
     {
-        for (; chooser->priv->monitors[id]; ++id)
+        for (id = 0; chooser->priv->monitors[id]; ++id)
         {
             monitor = chooser->priv->monitors[id];
 
@@ -268,21 +242,21 @@ rstto_monitor_chooser_paint(GtkWidget *widget, cairo_t *ctx)
             {
                 if (monitor->width > monitor->height)
                 {
-                    width = alloc_width*0.4;
+                    width = alloc_width * 0.4;
                     height = width;
-                } 
+                }
                 else
                 {
-                    height = alloc_width*0.4;
+                    height = alloc_width * 0.4;
                     width = height;
                 }
-                label = g_strdup_printf("%d", id+1);
+                label = g_strdup_printf ("%d", id + 1);
                 cairo_save (ctx);
                 paint_monitor (
                         widget,
                         ctx,
-                        (alloc_width/4) - (width/2.0),
-                        (alloc_height - height)/2.0,
+                        alloc_width / 4 - width / 2,
+                        (alloc_height - height) / 2,
                         width,
                         height,
                         label,
@@ -297,30 +271,27 @@ rstto_monitor_chooser_paint(GtkWidget *widget, cairo_t *ctx)
 
                 if (monitor->width > monitor->height)
                 {
-                    width = alloc_width*(0.4/((gdouble)row_width+1));
+                    width = alloc_width * 0.4 / (row_width + 1);
                     height = width;
-                } 
+                }
                 else
                 {
-                    height = alloc_width*(0.4/chooser->priv->n_monitors);
+                    height = alloc_width * 0.4 / chooser->priv->n_monitors;
                     width = height;
                 }
-            
 
-                label = g_strdup_printf("%d", id+1);
+                label = g_strdup_printf ("%d", id + 1);
                 cairo_save (ctx);
                 if (id < chooser->priv->selected)
                 {
                     paint_monitor (
                             widget,
                             ctx,
-                            (alloc_width/2)+
-                                ((alloc_width/2)/
-                                (row_width+1))*(id%(row_width)+1)-
-                                (width/2.0),
-                            (alloc_height/
-                                (row_width+2)*(id/row_width+1))-
-                                (height/2.0),
+                            alloc_width / 2
+                                + (1 + id % row_width) * alloc_width / (2 * (row_width + 1))
+                                - width / 2,
+                            (1 + id / row_width) * alloc_height / (row_width + 2)
+                                - height / 2,
                             width,
                             height,
                             label,
@@ -332,13 +303,11 @@ rstto_monitor_chooser_paint(GtkWidget *widget, cairo_t *ctx)
                     paint_monitor (
                             widget,
                             ctx,
-                            (alloc_width/2)+
-                                ((alloc_width/2)/
-                                (row_width+1))*((id-1)%(row_width)+1)-
-                                (width/2.0),
-                            (alloc_height/
-                                (row_width+2)*((id-1)/row_width+1))-
-                                (height/2.0),
+                            alloc_width / 2
+                                + (1 + (id - 1) % row_width) * alloc_width / (2 * (row_width + 1))
+                                - width / 2,
+                            (1 + (id - 1) / row_width) * alloc_height / (row_width + 2)
+                                - height / 2,
                             width,
                             height,
                             label,
@@ -359,7 +328,7 @@ rstto_monitor_chooser_paint(GtkWidget *widget, cairo_t *ctx)
             {
                 width = 200;
                 height = 200;
-            } 
+            }
             else
             {
                 height = 200;
@@ -369,8 +338,8 @@ rstto_monitor_chooser_paint(GtkWidget *widget, cairo_t *ctx)
             paint_monitor (
                     widget,
                     ctx,
-                    (alloc_width - width)/2.0,
-                    (alloc_height - height)/2.0,
+                    (alloc_width - width) / 2.0,
+                    (alloc_height - height) / 2.0,
                     width,
                     height,
                     "1",
@@ -384,15 +353,15 @@ rstto_monitor_chooser_paint(GtkWidget *widget, cairo_t *ctx)
 }
 
 static void
-paint_monitor ( GtkWidget *widget,
-                cairo_t *cr,
-                gdouble x,
-                gdouble y,
-                gdouble width,
-                gdouble height,
-                gchar *label,
-                Monitor *monitor,
-                gboolean active)
+paint_monitor (GtkWidget *widget,
+               cairo_t *cr,
+               gdouble x,
+               gdouble y,
+               gdouble width,
+               gdouble height,
+               gchar *label,
+               Monitor *monitor,
+               gboolean active)
 {
     /* Do we want the border_padding to be a percentage of the width
      * parmeter?
@@ -403,26 +372,23 @@ paint_monitor ( GtkWidget *widget,
 
     /* Assumption: monitor-width is always larger then monitor-height */
     /******************************************************************/
-    gdouble monitor_height = 
-            ( width - ( 2 * ( border_padding + monitor_border_width ) ) ) /
-            monitor->width * monitor->height;
-    gdouble monitor_width = 
-            width - ( 2 * ( border_padding + monitor_border_width ) );
+    gdouble monitor_height = monitor->height
+                             * (width - 2 * (border_padding + monitor_border_width))
+                             / monitor->width;
+    gdouble monitor_width = width - 2 * (border_padding + monitor_border_width);
 
     gdouble monitor_x = x + border_padding + monitor_border_width;
 
-    gdouble monitor_y = y +
-            ( height -
-                    ( ( border_padding + monitor_border_width ) * 2 ) -
-                    foot_height - monitor_height);
+    gdouble monitor_y = y + height
+                        - 2 * (border_padding + monitor_border_width)
+                        - foot_height - monitor_height;
 
     gdouble line_width = 2.0;
-    double radius = monitor_border_width * 0.5;
-    double degrees = M_PI / 180.0;
-    gint text_width = 0.0;
-    gint text_height = 0.0;
-    gdouble hscale = 1.0;
-    gdouble vscale = 1.0;
+    gdouble radius = monitor_border_width * 0.5;
+    gdouble degrees = M_PI / 180.0;
+    gdouble hscale, vscale;
+    gint text_width = 0;
+    gint text_height = 0;
 
     /*******************************************/
     PangoLayout *layout;
@@ -473,40 +439,40 @@ paint_monitor ( GtkWidget *widget,
     cairo_set_line_width (cr, line_width);
     cairo_stroke (cr);
 
-    /* Draw a monitor foot */ 
+    /* Draw a monitor foot */
     cairo_new_sub_path (cr);
     cairo_move_to (
             cr,
-            monitor_x+(monitor_width-foot_height)/2.0,
-            monitor_y+(monitor_height+monitor_border_width));
+            monitor_x + (monitor_width - foot_height) / 2.0,
+            monitor_y + monitor_height + monitor_border_width);
     cairo_line_to (
             cr,
-            monitor_x+(monitor_width-foot_height)/2.0+foot_height,
-            monitor_y+(monitor_height+monitor_border_width));
+            monitor_x + (monitor_width - foot_height) / 2.0 + foot_height,
+            monitor_y + monitor_height + monitor_border_width);
     cairo_line_to (
             cr,
-            monitor_x+(monitor_width-foot_height)/2.0+foot_height,
-            monitor_y+(monitor_height+monitor_border_width+foot_height*0.5));
+            monitor_x + (monitor_width - foot_height) / 2.0 + foot_height,
+            monitor_y + monitor_height + monitor_border_width + foot_height * 0.5);
     cairo_line_to (
             cr,
-            monitor_x+(monitor_width-foot_height)/2.0+foot_height*2,
-            monitor_y+(monitor_height+monitor_border_width+foot_height*0.5));
+            monitor_x + (monitor_width - foot_height) / 2.0 + foot_height * 2,
+            monitor_y + monitor_height + monitor_border_width + foot_height * 0.5);
     cairo_line_to (
             cr,
-            monitor_x+(monitor_width-foot_height)/2.0+foot_height*2,
-            monitor_y+(monitor_height+monitor_border_width+foot_height));
+            monitor_x + (monitor_width - foot_height) / 2.0 + foot_height * 2,
+            monitor_y + monitor_height + monitor_border_width + foot_height);
     cairo_line_to (
             cr,
-            monitor_x+(monitor_width-foot_height)/2.0-foot_height,
-            monitor_y+(monitor_height+monitor_border_width+foot_height));
+            monitor_x + (monitor_width - foot_height) / 2.0 - foot_height,
+            monitor_y + monitor_height + monitor_border_width + foot_height);
     cairo_line_to (
             cr,
-            monitor_x+(monitor_width-foot_height)/2.0-foot_height,
-            monitor_y+(monitor_height+monitor_border_width+foot_height*0.5));
+            monitor_x + (monitor_width - foot_height) / 2.0 - foot_height,
+            monitor_y + monitor_height + monitor_border_width + foot_height * 0.5);
     cairo_line_to (
             cr,
-            monitor_x+(monitor_width-foot_height)/2.0,
-            monitor_y+(monitor_height+monitor_border_width+foot_height*0.5));
+            monitor_x + (monitor_width - foot_height) / 2.0,
+            monitor_y + monitor_height + monitor_border_width + foot_height * 0.5);
     cairo_close_path (cr);
     cairo_set_source_rgba (cr, 1.0, 1.0, 1.0, 1.0); // white
     cairo_fill_preserve (cr);
@@ -517,8 +483,8 @@ paint_monitor ( GtkWidget *widget,
     /* Draw a line around the image */
     cairo_new_sub_path (cr);
     cairo_move_to (cr, monitor_x, monitor_y);
-    cairo_line_to (cr, monitor_x+monitor_width, monitor_y);
-    cairo_line_to (cr, monitor_x+monitor_width, monitor_y + monitor_height);
+    cairo_line_to (cr, monitor_x + monitor_width, monitor_y);
+    cairo_line_to (cr, monitor_x + monitor_width, monitor_y + monitor_height);
     cairo_line_to (cr, monitor_x, monitor_y + monitor_height);
     cairo_close_path (cr);
     cairo_set_source_rgba (cr, 0.231, 0.231, 0.231, 1.0); // dark gray-ish
@@ -528,8 +494,8 @@ paint_monitor ( GtkWidget *widget,
     /* Set the path that limits the image-size */
     cairo_new_sub_path (cr);
     cairo_move_to (cr, monitor_x, monitor_y);
-    cairo_line_to (cr, monitor_x+monitor_width, monitor_y);
-    cairo_line_to (cr, monitor_x+monitor_width, monitor_y + monitor_height);
+    cairo_line_to (cr, monitor_x + monitor_width, monitor_y);
+    cairo_line_to (cr, monitor_x + monitor_width, monitor_y + monitor_height);
     cairo_line_to (cr, monitor_x, monitor_y + monitor_height);
     cairo_close_path (cr);
 
@@ -541,23 +507,23 @@ paint_monitor ( GtkWidget *widget,
     {
         cairo_clip_preserve (cr);
 
-        hscale = monitor_width / (cairo_image_surface_get_width(monitor->image_surface));
-        vscale = monitor_height / (cairo_image_surface_get_height(monitor->image_surface));
+        hscale = monitor_width / cairo_image_surface_get_width (monitor->image_surface);
+        vscale = monitor_height / cairo_image_surface_get_height (monitor->image_surface);
 
         cairo_scale (cr, hscale, vscale);
 
         cairo_set_source_surface (
                 cr,
                 monitor->image_surface,
-                monitor_x/hscale,
-                monitor_y/vscale);
-        cairo_paint(cr);
+                monitor_x / hscale,
+                monitor_y / vscale);
+        cairo_paint (cr);
 
-        cairo_reset_clip(cr);
-        cairo_scale (cr, 1/hscale, 1/vscale);
+        cairo_reset_clip (cr);
+        cairo_scale (cr, 1 / hscale, 1 / vscale);
     }
 
-    if (FALSE == active)
+    if (! active)
     {
         cairo_set_source_rgba (cr, 1.0, 1.0, 1.0, 0.6);
         cairo_fill_preserve (cr);
@@ -571,7 +537,7 @@ paint_monitor ( GtkWidget *widget,
     font_description = pango_font_description_new ();
     pango_font_description_set_family (font_description, "sans");
     pango_font_description_set_weight (font_description, PANGO_WEIGHT_BOLD);
-    pango_font_description_set_absolute_size (font_description, height*0.3 * PANGO_SCALE);
+    pango_font_description_set_absolute_size (font_description, height * 0.3 * PANGO_SCALE);
 
 
     layout = pango_cairo_create_layout (cr);
@@ -579,12 +545,12 @@ paint_monitor ( GtkWidget *widget,
     pango_layout_set_text (layout, label, -1);
     pango_layout_set_alignment (layout, PANGO_ALIGN_CENTER);
     pango_cairo_update_layout (cr, layout);
-    pango_layout_get_pixel_size (layout, &text_width, &text_height); 
+    pango_layout_get_pixel_size (layout, &text_width, &text_height);
 
     cairo_move_to (
             cr,
-            monitor_x+(monitor_width-(gdouble)text_width) / 2,
-            monitor_y+(monitor_height- (gdouble)text_height) / 2);
+            monitor_x + (monitor_width - text_width) / 2,
+            monitor_y + (monitor_height - text_height) / 2);
     pango_cairo_layout_path (cr, layout);
     cairo_set_source_rgba (cr, 1.0, 1.0, 1.0, 0.8);
     cairo_fill_preserve (cr);
@@ -602,13 +568,13 @@ paint_monitor ( GtkWidget *widget,
  * @Returns: a new monitor-chooser object.
  */
 GtkWidget *
-rstto_monitor_chooser_new ( void )
+rstto_monitor_chooser_new (void)
 {
     RsttoMonitorChooser *chooser;
 
-    chooser = g_object_new(RSTTO_TYPE_MONITOR_CHOOSER, NULL);
+    chooser = g_object_new (RSTTO_TYPE_MONITOR_CHOOSER, NULL);
 
-    return GTK_WIDGET(chooser);
+    return GTK_WIDGET (chooser);
 }
 
 /**
@@ -620,12 +586,12 @@ rstto_monitor_chooser_new ( void )
  * Add a monitor to the monitor-chooser.
  */
 gint
-rstto_monitor_chooser_add ( 
+rstto_monitor_chooser_add (
         RsttoMonitorChooser *chooser,
         gint width,
         gint height)
 {
-    Monitor **monitors = g_new0 (Monitor *, chooser->priv->n_monitors+2);
+    Monitor **monitors = g_new0 (Monitor *, chooser->priv->n_monitors + 2);
     gint id = 0;
 
     Monitor *monitor = g_new0 (Monitor, 1);
@@ -646,7 +612,7 @@ rstto_monitor_chooser_add (
         }
         g_free (chooser->priv->monitors);
     }
-    
+
     monitors[id] = monitor;
 
     chooser->priv->monitors = monitors;
@@ -663,7 +629,7 @@ rstto_monitor_chooser_add (
  * @error:
  *
  * Set the image-surface for a specific monitor. (the image visible in
- * the monitor )
+ * the monitor)
  */
 gint
 rstto_monitor_chooser_set_image_surface (
@@ -708,57 +674,42 @@ rstto_monitor_chooser_set_image_surface (
 static void
 cb_rstto_button_press_event (
         GtkWidget *widget,
-        GdkEventButton *event )
+        GdkEventButton *event)
 {
-    RsttoMonitorChooser *chooser = RSTTO_MONITOR_CHOOSER(widget);
-    gint row_width = 0;
-    gint id = 0;
-    gint width, height;
+    RsttoMonitorChooser *chooser = RSTTO_MONITOR_CHOOSER (widget);
     GtkAllocation allocation;
-    
+    gdouble tmp_x, tmp_y;
+    gint row_width, id, width, height;
+
     if (chooser->priv->n_monitors > 1)
     {
         row_width = sqrt (chooser->priv->n_monitors);
 
         gtk_widget_get_allocation (widget, &allocation);
-        width = allocation.width*(0.4/((gdouble)row_width+1));
+        width = allocation.width * 0.4 / (row_width + 1);
         height = width;
 
         for (id = 0; id < chooser->priv->n_monitors; ++id)
         {
-            if ( (event->x > ((gdouble)allocation.width/2)+
-                                (((gdouble)allocation.width/2)/
-                                (row_width+1))*(id%(row_width)+1)-
-                                (width/2.0)) &&
-                 (event->x < ((gdouble)allocation.width/2)+
-                                (((gdouble)allocation.width/2)/
-                                (row_width+1))*(id%(row_width)+1)+
-                                (width/2.0)) &&
-                 (event->y > ((gdouble)allocation.height/
-                                (row_width+2)*(id/row_width+1)-
-                                (height/2.0))) &&
-                 (event->y < ((gdouble)allocation.height/
-                                (row_width+2)*(id/row_width+1)+
-                                (height/2.0))))
+            tmp_x = allocation.width / 2.0
+                    + (1 + id % row_width) * allocation.width / (2.0 * (row_width + 1));
+            tmp_y = (1 + id / row_width) * (gdouble) allocation.height / (row_width + 2);
+
+            if (event->x > tmp_x - width / 2.0 && event->x < tmp_x + width / 2.0
+                && event->y > tmp_y - height / 2.0 && event->y < tmp_y + height / 2.0)
             {
                 if (id < chooser->priv->selected)
-                {
                     chooser->priv->selected = id;
-                }
-                else
-                {
-                    if (id+1 != chooser->priv->n_monitors)
-                    {
-                        chooser->priv->selected = id+1;
-                    }
-                }
+                else if (id + 1 != chooser->priv->n_monitors)
+                    chooser->priv->selected = id + 1;
 
-                g_signal_emit (G_OBJECT (chooser), rstto_monitor_chooser_signals[RSTTO_MONITOR_CHOOSER_SIGNAL_CHANGED], 0, NULL);
+                g_signal_emit (chooser,
+                               rstto_monitor_chooser_signals[RSTTO_MONITOR_CHOOSER_SIGNAL_CHANGED],
+                               0, NULL);
 
                 gtk_widget_queue_draw (widget);
             }
         }
-
     }
 }
 
@@ -770,7 +721,7 @@ cb_rstto_button_press_event (
  */
 gint
 rstto_monitor_chooser_get_selected (
-        RsttoMonitorChooser *chooser )
+        RsttoMonitorChooser *chooser)
 {
     return chooser->priv->selected;
 }
