@@ -5,77 +5,32 @@
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
  *  of the License, or (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- * 
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  *  02110-1301, USA.
  */
 
-#include <config.h>
-
 #include <string.h>
 
 #include <glib.h>
 #include <gio/gio.h>
 
-#include <libexif/exif-data.h>
-
 #include <libxfce4util/libxfce4util.h>
 
 #include "util.h"
 #include "file.h"
 #include "settings.h"
 #include "thumbnailer.h"
-#include "marshal.h"
 #include "tumbler.h"
 
-static void
-rstto_thumbnailer_init (GObject *);
-static void
-rstto_thumbnailer_class_init (GObjectClass *);
 
-static void
-rstto_thumbnailer_dispose (GObject *object);
-static void
-rstto_thumbnailer_finalize (GObject *object);
-
-static void
-rstto_thumbnailer_set_property (
-        GObject      *object,
-        guint         property_id,
-        const GValue *value,
-        GParamSpec   *pspec);
-static void
-rstto_thumbnailer_get_property (
-        GObject    *object,
-        guint       property_id,
-        GValue     *value,
-        GParamSpec *pspec);
-
-static void
-cb_rstto_thumbnailer_request_finished (
-        TumblerThumbnailer1 *proxy,
-        guint arg_handle,
-        gpointer data);
-static void
-cb_rstto_thumbnailer_thumbnail_ready (
-        TumblerThumbnailer1 *proxy,
-        guint handle,
-        const gchar *const *uri,
-        gpointer data);
-
-static gboolean
-rstto_thumbnailer_queue_request_timer (RsttoThumbnailer *thumbnailer);
-
-static GObjectClass *parent_class = NULL;
-
-static RsttoThumbnailer *thumbnailer_object;
 
 enum
 {
@@ -85,65 +40,57 @@ enum
 
 static gint rstto_thumbnailer_signals[RSTTO_THUMBNAILER_SIGNAL_COUNT];
 
-enum
-{
-    PROP_0,
-};
+static RsttoThumbnailer *thumbnailer_object;
 
-GType
-rstto_thumbnailer_get_type (void)
-{
-    static GType rstto_thumbnailer_type = 0;
 
-    if (!rstto_thumbnailer_type)
-    {
-        static const GTypeInfo rstto_thumbnailer_info = 
-        {
-            sizeof (RsttoThumbnailerClass),
-            (GBaseInitFunc) NULL,
-            (GBaseFinalizeFunc) NULL,
-            (GClassInitFunc) rstto_thumbnailer_class_init,
-            (GClassFinalizeFunc) NULL,
-            NULL,
-            sizeof (RsttoThumbnailer),
-            0,
-            (GInstanceInitFunc) rstto_thumbnailer_init,
-            NULL
-        };
 
-        rstto_thumbnailer_type = g_type_register_static (
-                G_TYPE_OBJECT,
-                "RsttoThumbnailer",
-                &rstto_thumbnailer_info,
-                0);
-    }
-    return rstto_thumbnailer_type;
-}
+static void
+rstto_thumbnailer_finalize (GObject *object);
 
-struct _RsttoThumbnailerPriv
+static void
+cb_rstto_thumbnailer_request_finished (TumblerThumbnailer1 *proxy,
+                                       guint arg_handle,
+                                       gpointer data);
+static void
+cb_rstto_thumbnailer_thumbnail_ready (TumblerThumbnailer1 *proxy,
+                                      guint handle,
+                                      const gchar *const *uri,
+                                      gpointer data);
+static gboolean
+rstto_thumbnailer_queue_request_timer (gpointer user_data);
+
+
+
+struct _RsttoThumbnailerPrivate
 {
     GDBusConnection     *connection;
     TumblerThumbnailer1 *proxy;
     RsttoSettings       *settings;
+    RsttoImageList      *image_list;
 
     GSList              *queue;
+    gint                 n_visible_items;
 
     GSList              *in_process_queue;
     guint                handle;
 
     gboolean             show_missing_thumbnailer_error;
 
-    gint                 request_timer_id;
+    guint                request_timer_id;
 };
 
-static void
-rstto_thumbnailer_init (GObject *object)
-{
-    RsttoThumbnailer *thumbnailer = RSTTO_THUMBNAILER (object);
 
-    thumbnailer->priv = g_new0 (RsttoThumbnailerPriv, 1);
-    thumbnailer->priv->connection = g_bus_get_sync(G_BUS_TYPE_SESSION, NULL, NULL);
-    thumbnailer->priv->settings = rstto_settings_new();
+
+G_DEFINE_TYPE_WITH_PRIVATE (RsttoThumbnailer, rstto_thumbnailer, G_TYPE_OBJECT)
+
+
+
+static void
+rstto_thumbnailer_init (RsttoThumbnailer *thumbnailer)
+{
+    thumbnailer->priv = rstto_thumbnailer_get_instance_private (thumbnailer);
+    thumbnailer->priv->connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+    thumbnailer->priv->settings = rstto_settings_new ();
 
     thumbnailer->priv->show_missing_thumbnailer_error =
             rstto_settings_get_boolean_property (
@@ -152,7 +99,6 @@ rstto_thumbnailer_init (GObject *object)
 
     if (thumbnailer->priv->connection)
     {
-    
         thumbnailer->priv->proxy = tumbler_thumbnailer1_proxy_new_sync (
                 thumbnailer->priv->connection,
                 G_DBUS_PROXY_FLAGS_NONE,
@@ -161,35 +107,27 @@ rstto_thumbnailer_init (GObject *object)
                 NULL,
                 NULL);
 
-        g_signal_connect(thumbnailer->priv->proxy,
+        g_signal_connect (thumbnailer->priv->proxy,
                          "finished",
                          G_CALLBACK (cb_rstto_thumbnailer_request_finished),
                          thumbnailer);
-        g_signal_connect(thumbnailer->priv->proxy,
+        g_signal_connect (thumbnailer->priv->proxy,
                          "ready",
-                         G_CALLBACK(cb_rstto_thumbnailer_thumbnail_ready),
+                         G_CALLBACK (cb_rstto_thumbnailer_thumbnail_ready),
                          thumbnailer);
     }
 }
 
 
 static void
-rstto_thumbnailer_class_init (GObjectClass *object_class)
+rstto_thumbnailer_class_init (RsttoThumbnailerClass *klass)
 {
-    RsttoThumbnailerClass *thumbnailer_class = RSTTO_THUMBNAILER_CLASS (
-            object_class);
+    GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-    parent_class = g_type_class_peek_parent (thumbnailer_class);
-
-    object_class->dispose = rstto_thumbnailer_dispose;
     object_class->finalize = rstto_thumbnailer_finalize;
 
-    object_class->set_property = rstto_thumbnailer_set_property;
-    object_class->get_property = rstto_thumbnailer_get_property;
-
-
-    rstto_thumbnailer_signals[RSTTO_THUMBNAILER_SIGNAL_READY] = g_signal_new("ready",
-            G_TYPE_FROM_CLASS(thumbnailer_class),
+    rstto_thumbnailer_signals[RSTTO_THUMBNAILER_SIGNAL_READY] = g_signal_new ("ready",
+            G_TYPE_FROM_CLASS (klass),
             G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION,
             0,
             NULL,
@@ -201,27 +139,6 @@ rstto_thumbnailer_class_init (GObjectClass *object_class)
             NULL);
 }
 
-/**
- * rstto_thumbnailer_dispose:
- * @object:
- *
- */
-static void
-rstto_thumbnailer_dispose (GObject *object)
-{
-    RsttoThumbnailer *thumbnailer = RSTTO_THUMBNAILER (object);
-
-    if (thumbnailer->priv)
-    {
-        g_clear_object (&thumbnailer->priv->settings);
-        g_clear_object (&thumbnailer->priv->proxy);
-        g_clear_object (&thumbnailer->priv->connection);
-        g_slist_free_full (thumbnailer->priv->queue, g_object_unref);
-
-        g_clear_pointer (&thumbnailer->priv, g_free);
-    }
-}
-
 /**
  * rstto_thumbnailer_finalize:
  * @object:
@@ -230,6 +147,14 @@ rstto_thumbnailer_dispose (GObject *object)
 static void
 rstto_thumbnailer_finalize (GObject *object)
 {
+    RsttoThumbnailer *thumbnailer = RSTTO_THUMBNAILER (object);
+
+    g_clear_object (&thumbnailer->priv->settings);
+    g_clear_object (&thumbnailer->priv->proxy);
+    g_clear_object (&thumbnailer->priv->connection);
+    g_slist_free_full (thumbnailer->priv->queue, g_object_unref);
+
+    G_OBJECT_CLASS (rstto_thumbnailer_parent_class)->finalize (object);
 }
 
 
@@ -255,54 +180,22 @@ rstto_thumbnailer_new (void)
     return thumbnailer_object;
 }
 
-
-static void
-rstto_thumbnailer_set_property (
-        GObject      *object,
-        guint         property_id,
-        const GValue *value,
-        GParamSpec   *pspec)
-{
-    switch (property_id)
-    {
-        default:
-            break;
-    }
-}
-
-static void
-rstto_thumbnailer_get_property (
-        GObject    *object,
-        guint       property_id,
-        GValue     *value,
-        GParamSpec *pspec)
-{
-    switch (property_id)
-    {
-        default:
-            break;
-    }
-}
-
 void
 rstto_thumbnailer_queue_file (
         RsttoThumbnailer *thumbnailer,
-        RsttoFile *file )
+        RsttoFile *file)
 {
-    g_return_if_fail ( RSTTO_IS_THUMBNAILER (thumbnailer) );
+    g_return_if_fail (RSTTO_IS_THUMBNAILER (thumbnailer));
+    g_return_if_fail (RSTTO_IS_FILE (file));
 
-    g_return_if_fail ( RSTTO_IS_FILE (file) );
-
-    if (thumbnailer->priv->request_timer_id)
+    if (thumbnailer->priv->request_timer_id != 0)
     {
-        g_source_remove (thumbnailer->priv->request_timer_id);
+        REMOVE_SOURCE (thumbnailer->priv->request_timer_id);
         if (thumbnailer->priv->handle)
         {
-            if(tumbler_thumbnailer1_call_dequeue_sync(
-                thumbnailer->priv->proxy,
-                thumbnailer->priv->handle,
-                NULL,
-                NULL) == FALSE)
+            if (! tumbler_thumbnailer1_call_dequeue_sync (thumbnailer->priv->proxy,
+                                                          thumbnailer->priv->handle,
+                                                          NULL, NULL))
             {
                 /* If this fails it usually means there's a thumbnail already
                  * being processed, no big deal */
@@ -311,19 +204,14 @@ rstto_thumbnailer_queue_file (
         }
     }
 
-    if (g_slist_find (thumbnailer->priv->queue, file) == NULL)
-    {
-        g_object_ref (file);
-        thumbnailer->priv->queue = g_slist_prepend (
-                thumbnailer->priv->queue,
-                file);
-    }
+    g_object_ref (file);
+    thumbnailer->priv->queue = g_slist_prepend (thumbnailer->priv->queue, file);
 
-    thumbnailer->priv->request_timer_id = gdk_threads_add_timeout_full (
+    thumbnailer->priv->request_timer_id = g_timeout_add_full (
             G_PRIORITY_LOW,
             300,
-            (GSourceFunc)rstto_thumbnailer_queue_request_timer,
-            thumbnailer,
+            rstto_thumbnailer_queue_request_timer,
+            rstto_util_source_autoremove (thumbnailer),
             NULL);
 }
 
@@ -332,102 +220,103 @@ rstto_thumbnailer_dequeue_file (
         RsttoThumbnailer *thumbnailer,
         RsttoFile *file)
 {
-    g_return_if_fail ( RSTTO_IS_THUMBNAILER (thumbnailer) );
+    g_return_if_fail (RSTTO_IS_THUMBNAILER (thumbnailer));
+
+    g_return_if_fail (RSTTO_IS_FILE (file));
 
-    g_return_if_fail ( RSTTO_IS_FILE (file) );
-    
     if (thumbnailer->priv->request_timer_id)
     {
-        g_source_remove (thumbnailer->priv->request_timer_id);
+        REMOVE_SOURCE (thumbnailer->priv->request_timer_id);
     }
 
     if (thumbnailer->priv->handle)
     {
-        if(tumbler_thumbnailer1_call_dequeue_sync(
-                thumbnailer->priv->proxy,
-                thumbnailer->priv->handle,
-                NULL,
-                NULL) == FALSE)
+        if (! tumbler_thumbnailer1_call_dequeue_sync (thumbnailer->priv->proxy,
+                                                      thumbnailer->priv->handle,
+                                                      NULL, NULL))
         {
             /* If this fails it usually means there's a thumbnail already
              * being processed, no big deal */
         }
         thumbnailer->priv->handle = 0;
-        g_slist_free_full (thumbnailer->priv->in_process_queue, (GDestroyNotify) g_object_unref);
+        g_slist_free_full (thumbnailer->priv->in_process_queue, g_object_unref);
         thumbnailer->priv->in_process_queue = NULL;
     }
 
-    if (g_slist_find (thumbnailer->priv->queue, file) != NULL)
-    {
-        thumbnailer->priv->queue = g_slist_remove_all (
-                thumbnailer->priv->queue,
-                file);
-        g_object_unref (file);
-    }
+    thumbnailer->priv->queue = g_slist_remove_all (thumbnailer->priv->queue, file);
+    g_object_unref (file);
 
-    thumbnailer->priv->request_timer_id = gdk_threads_add_timeout_full (
+    thumbnailer->priv->request_timer_id = g_timeout_add_full (
             G_PRIORITY_LOW,
             300,
-            (GSourceFunc)rstto_thumbnailer_queue_request_timer,
-            thumbnailer,
+            rstto_thumbnailer_queue_request_timer,
+            rstto_util_source_autoremove (thumbnailer),
             NULL);
 }
 
-static gboolean
-rstto_thumbnailer_queue_request_timer (
-        RsttoThumbnailer *thumbnailer)
+void
+rstto_thumbnailer_set_image_list (RsttoThumbnailer *thumbnailer,
+                                  RsttoImageList   *image_list)
 {
-    const gchar **uris;
-    const gchar **mimetypes;
-    GSList *iter;
-    gint i = 0;
-    RsttoFile *file;
-    GError *error = NULL;
-    GtkWidget *error_dialog = NULL;
-    GtkWidget *vbox, *do_not_show_checkbox;
+    /* we don't take a ref here, this would uselessly put us into a ref counting cycle */
+    thumbnailer->priv->image_list = image_list;
+}
 
-    g_return_val_if_fail ( RSTTO_IS_THUMBNAILER (thumbnailer), FALSE);
+void
+rstto_thumbnailer_set_n_visible_items (RsttoThumbnailer *thumbnailer,
+                                       gint n_items)
+{
+    thumbnailer->priv->n_visible_items = n_items;
+}
+
+static gboolean
+rstto_thumbnailer_queue_request_timer (gpointer user_data)
+{
+    RsttoThumbnailer *thumbnailer = user_data;
+    GtkWidget *error_dialog, *vbox, *do_not_show_checkbox;
+    GSList *iter;
+    GError *error = NULL;
+    const gchar **uris, **mimetypes;
+    gint i;
+
+    g_return_val_if_fail (RSTTO_IS_THUMBNAILER (thumbnailer), FALSE);
 
     thumbnailer->priv->in_process_queue = thumbnailer->priv->queue;
     thumbnailer->priv->queue = NULL;
 
-    uris = g_new0 (
-            const gchar *,
-            g_slist_length(thumbnailer->priv->in_process_queue) + 1);
-    mimetypes = g_new0 (
-            const gchar *,
-            g_slist_length (thumbnailer->priv->in_process_queue) + 1);
+    uris = g_new0 (const gchar *, thumbnailer->priv->n_visible_items + 1);
+    mimetypes = g_new0 (const gchar *, thumbnailer->priv->n_visible_items + 1);
 
-    iter = thumbnailer->priv->in_process_queue;
-    while (iter)
+    for (iter = thumbnailer->priv->in_process_queue, i = 0;
+         iter != NULL && i < thumbnailer->priv->n_visible_items;
+         iter = iter->next)
     {
-        if (iter->data)
+        /* directories are loaded without this costly filtering, so it is done
+         * here only when required */
+        if (! rstto_file_is_valid (iter->data))
         {
-            file = RSTTO_FILE(iter->data);
-            uris[i] = rstto_file_get_uri (file);
-            mimetypes[i] = rstto_file_get_content_type (file);
+            rstto_image_list_remove_file (thumbnailer->priv->image_list, iter->data);
+            continue;
         }
-        iter = g_slist_next(iter);
+
+        uris[i] = rstto_file_get_uri (iter->data);
+        mimetypes[i] = rstto_file_get_content_type (iter->data);
         i++;
     }
 
-    if(tumbler_thumbnailer1_call_queue_sync(
-        thumbnailer->priv->proxy,
-        (const gchar * const*)uris,
-        (const gchar * const*)mimetypes,
-        "normal",
-        "default",
-        0,
-        &thumbnailer->priv->handle,
-        NULL,
-        &error) == FALSE)
+    if (! tumbler_thumbnailer1_call_queue_sync (thumbnailer->priv->proxy,
+                                                (const gchar * const*) uris,
+                                                (const gchar * const*) mimetypes,
+                                                "normal", "default", 0,
+                                                &thumbnailer->priv->handle,
+                                                NULL, &error))
     {
         if (NULL != error)
         {
-            g_warning("DBUS-call failed:%s", error->message);
-            if ((error->domain == G_DBUS_ERROR) &&
-                (error->code == G_DBUS_ERROR_SERVICE_UNKNOWN) &&
-                thumbnailer->priv->show_missing_thumbnailer_error == TRUE)
+            g_warning ("DBUS-call failed:%s", error->message);
+            if (error->domain == G_DBUS_ERROR
+                && error->code == G_DBUS_ERROR_SERVICE_UNKNOWN
+                && thumbnailer->priv->show_missing_thumbnailer_error)
             {
                 error_dialog = gtk_message_dialog_new_with_markup (
                         NULL,
@@ -438,8 +327,7 @@ rstto_thumbnailer_queue_request_timer (
                         "for this reason, the thumbnails can not be\n"
                         "created.\n\n"
                         "Install <b>Tumbler</b> or another <i>thumbnailing daemon</i>\n"
-                        "to resolve this issue.")
-                        );
+                        "to resolve this issue."));
                 vbox = gtk_dialog_get_content_area (
                         GTK_DIALOG (error_dialog));
 
@@ -452,11 +340,10 @@ rstto_thumbnailer_queue_request_timer (
                         FALSE,
                         0);
                 gtk_widget_show (do_not_show_checkbox);
-                gtk_dialog_run (GTK_DIALOG(error_dialog));
+                gtk_dialog_run (GTK_DIALOG (error_dialog));
 
                 thumbnailer->priv->show_missing_thumbnailer_error = FALSE;
-                if (TRUE == gtk_toggle_button_get_active (
-                        GTK_TOGGLE_BUTTON (do_not_show_checkbox)))
+                if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (do_not_show_checkbox)))
                 {
                     rstto_settings_set_boolean_property (
                         thumbnailer->priv->settings,
@@ -468,7 +355,7 @@ rstto_thumbnailer_queue_request_timer (
         }
         /* TOOO: Nice cleanup */
     }
-    
+
     g_free (uris);
     g_free (mimetypes);
 
@@ -482,13 +369,13 @@ cb_rstto_thumbnailer_request_finished (
         guint arg_handle,
         gpointer data)
 {
-    RsttoThumbnailer *thumbnailer = RSTTO_THUMBNAILER (data);
+    RsttoThumbnailer *thumbnailer = data;
 
-    g_return_if_fail ( RSTTO_IS_THUMBNAILER (thumbnailer) );
+    g_return_if_fail (RSTTO_IS_THUMBNAILER (thumbnailer));
 
     if (thumbnailer->priv->in_process_queue)
     {
-        g_slist_free_full (thumbnailer->priv->in_process_queue, (GDestroyNotify) g_object_unref);
+        g_slist_free_full (thumbnailer->priv->in_process_queue, g_object_unref);
         thumbnailer->priv->in_process_queue = NULL;
     }
 }
@@ -500,13 +387,13 @@ cb_rstto_thumbnailer_thumbnail_ready (
         const gchar *const *uri,
         gpointer data)
 {
-    RsttoThumbnailer *thumbnailer = RSTTO_THUMBNAILER (data);
+    RsttoThumbnailer *thumbnailer = data;
     RsttoFile *file;
     GSList *iter = thumbnailer->priv->in_process_queue;
     gint x = 0;
     const gchar *f_uri;
 
-    g_return_if_fail ( RSTTO_IS_THUMBNAILER (thumbnailer) );
+    g_return_if_fail (RSTTO_IS_THUMBNAILER (thumbnailer));
 
     while (iter)
     {
@@ -515,16 +402,13 @@ cb_rstto_thumbnailer_thumbnail_ready (
             break;
         }
 
-        file = RSTTO_FILE (iter->data);
+        file = iter->data;
         f_uri = rstto_file_get_uri (file);
         if (strcmp (uri[x], f_uri) == 0)
         {
-            g_signal_emit (
-                    G_OBJECT (thumbnailer),
-                    rstto_thumbnailer_signals[RSTTO_THUMBNAILER_SIGNAL_READY],
-                    0,
-                    file,
-                    NULL);
+            g_signal_emit (thumbnailer,
+                           rstto_thumbnailer_signals[RSTTO_THUMBNAILER_SIGNAL_READY],
+                           0, file, NULL);
             thumbnailer->priv->in_process_queue = g_slist_remove (
                     thumbnailer->priv->in_process_queue,
                     file);
@@ -535,7 +419,7 @@ cb_rstto_thumbnailer_thumbnail_ready (
         }
         else
         {
-            iter = g_slist_next(iter);
+            iter = g_slist_next (iter);
         }
-    } 
+    }
 }
