@@ -5,12 +5,12 @@
  *  modify it under the terms of the GNU General Public License
  *  as published by the Free Software Foundation; either version 2
  *  of the License, or (at your option) any later version.
- * 
+ *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *  GNU General Public License for more details.
- * 
+ *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
@@ -22,7 +22,13 @@
 
 #include "wallpaper_manager.h"
 
-gint 
+
+
+G_DEFINE_INTERFACE (RsttoWallpaperManager, rstto_wallpaper_manager, G_TYPE_OBJECT)
+
+
+
+gint
 rstto_wallpaper_manager_configure_dialog_run (
         RsttoWallpaperManager *self,
         RsttoFile *file,
@@ -31,7 +37,7 @@ rstto_wallpaper_manager_configure_dialog_run (
     return RSTTO_WALLPAPER_MANAGER_GET_IFACE (self)->configure_dialog_run (self, file, parent);
 }
 
-gboolean 
+gboolean
 rstto_wallpaper_manager_check_running (RsttoWallpaperManager *self)
 {
     return RSTTO_WALLPAPER_MANAGER_GET_IFACE (self)->check_running (self);
@@ -47,28 +53,6 @@ rstto_wallpaper_manager_set (
 
 
 static void
-rstto_wallpaper_manager_iface_init (gpointer g_iface)
+rstto_wallpaper_manager_default_init (RsttoWallpaperManagerInterface *klass)
 {
 }
-
-
-GType 
-rstto_wallpaper_manager_get_type (void)
-{
-    static GType iface_type = 0;
-    if (iface_type == 0)
-    {
-        static const GTypeInfo info = {
-            /* other fields are initialized to 0 */
-            .class_size = sizeof (RsttoWallpaperManagerIface),
-            .base_init = rstto_wallpaper_manager_iface_init,
-        };
-
-        iface_type = g_type_register_static (
-                G_TYPE_INTERFACE,
-                "RsttoWallpaperManagerIface",
-                &info, 0);
-    }
-
-    return iface_type;
-}
